"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def simulate(
    hub,
    ctx,
    policy_input_list: List,
    action_names: List,
    permissions_boundary_policy_input_list: List = None,
    resource_arns: List = None,
    resource_policy: str = None,
    resource_owner: str = None,
    caller_arn: str = None,
    context_entries: List = None,
    resource_handling_option: str = None,
    max_items: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Simulate how a set of IAM policies and optionally a resource-based policy works with a list of API operations and Amazon Web Services resources to determine the policies' effective permissions. The policies are provided as strings. The simulation does not perform the API operations; it only checks the authorization to determine if the simulated policies allow or deny the operations. You can simulate resources that don't exist in your account. If you want to simulate existing policies that are attached to an IAM user, group, or role, use SimulatePrincipalPolicy instead. Context keys are variables that are maintained by Amazon Web Services and its services and which provide details about the context of an API query request. You can use the Condition element of an IAM policy to evaluate context keys. To get the list of context keys that the policies require for correct simulation, use GetContextKeysForCustomPolicy. If the output is long, you can use MaxItems and Marker parameters to paginate the results. For more information about using the policy simulator, see Testing IAM policies with the IAM policy simulator in the IAM User Guide.

    Args:
        policy_input_list(List): A list of policy documents to include in the simulation. Each document is specified as a string containing the complete, valid JSON text of an IAM policy. Do not include any resource-based policies in this parameter. Any resource-based policy must be submitted with the ResourcePolicy parameter. The policies cannot be "scope-down" policies, such as you could include in a call to GetFederationToken or one of the AssumeRole API operations. In other words, do not use policies designed to restrict what a user can do while using the temporary credentials. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
        permissions_boundary_policy_input_list(List, optional): The IAM permissions boundary policy to simulate. The permissions boundary sets the maximum permissions that an IAM entity can have. You can input only one permissions boundary when you pass a policy to this operation. For more information about permissions boundaries, see Permissions boundaries for IAM entities in the IAM User Guide. The policy input is specified as a string that contains the complete, valid JSON text of a permissions boundary policy. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        action_names(List): A list of names of API operations to evaluate in the simulation. Each operation is evaluated against each resource. Each operation must include the service identifier, such as iam:CreateUser. This operation does not support using wildcards (*) in an action name.
        resource_arns(List, optional): A list of ARNs of Amazon Web Services resources to include in the simulation. If this parameter is not provided, then the value defaults to * (all resources). Each API in the ActionNames parameter is evaluated for each resource in this list. The simulation determines the access result (allowed or denied) of each combination and reports it in the response. You can simulate resources that don't exist in your account. The simulation does not automatically retrieve policies for the specified resources. If you want to include a resource policy in the simulation, then you must include the policy as a string in the ResourcePolicy parameter. If you include a ResourcePolicy, then it must be applicable to all of the resources included in the simulation or you receive an invalid input error. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. Defaults to None.
        resource_policy(str, optional): A resource-based policy to include in the simulation provided as a string. Each resource in the simulation is treated as if it had this policy attached. You can include only one resource-based policy in a simulation. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        resource_owner(str, optional): An ARN representing the account ID that specifies the owner of any simulated resource that does not identify its owner in the resource ARN. Examples of resource ARNs include an S3 bucket or object. If ResourceOwner is specified, it is also used as the account owner of any ResourcePolicy included in the simulation. If the ResourceOwner parameter is not specified, then the owner of the resources and the resource policy defaults to the account of the identity provided in CallerArn. This parameter is required only if you specify a resource-based policy and account that owns the resource is different from the account that owns the simulated calling user CallerArn. The ARN for an account uses the following syntax: arn:aws:iam::AWS-account-ID:root. For example, to represent the account with the 112233445566 ID, use the following ARN: arn:aws:iam::112233445566-ID:root. . Defaults to None.
        caller_arn(str, optional): The ARN of the IAM user that you want to use as the simulated caller of the API operations. CallerArn is required if you include a ResourcePolicy so that the policy's Principal element has a value to use in evaluating the policy. You can specify only the ARN of an IAM user. You cannot specify the ARN of an assumed role, federated user, or a service principal. Defaults to None.
        context_entries(List, optional): A list of context keys and corresponding values for the simulation to use. Whenever a context key is evaluated in one of the simulated IAM permissions policies, the corresponding value is supplied. Defaults to None.
        resource_handling_option(str, optional): Specifies the type of simulation to run. Different API operations that support resource-based policies require different combinations of resources. By specifying the type of simulation to run, you enable the policy simulator to enforce the presence of the required resources to ensure reliable simulation results. If your simulation does not match one of the following scenarios, then you can omit this parameter. The following list shows each of the supported scenario values and the resources that you must define to run the simulation. Each of the EC2 scenarios requires that you specify instance, image, and security-group resources. If your scenario includes an EBS volume, then you must specify that volume as a resource. If the EC2 scenario includes VPC, then you must supply the network-interface resource. If it includes an IP subnet, then you must specify the subnet resource. For more information on the EC2 scenario options, see Supported platforms in the Amazon EC2 User Guide.    EC2-Classic-InstanceStore  instance, image, security-group    EC2-Classic-EBS  instance, image, security-group, volume    EC2-VPC-InstanceStore  instance, image, security-group, network-interface    EC2-VPC-InstanceStore-Subnet  instance, image, security-group, network-interface, subnet    EC2-VPC-EBS  instance, image, security-group, network-interface, volume    EC2-VPC-EBS-Subnet  instance, image, security-group, network-interface, subnet, volume  . Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.custom_policy.simulate(
                ctx, policy_input_list=value, action_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.custom_policy.simulate policy_input_list=value, action_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="simulate_custom_policy",
        op_kwargs={
            "PolicyInputList": policy_input_list,
            "PermissionsBoundaryPolicyInputList": permissions_boundary_policy_input_list,
            "ActionNames": action_names,
            "ResourceArns": resource_arns,
            "ResourcePolicy": resource_policy,
            "ResourceOwner": resource_owner,
            "CallerArn": caller_arn,
            "ContextEntries": context_entries,
            "ResourceHandlingOption": resource_handling_option,
            "MaxItems": max_items,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, cluster_operation_arn: str) -> Dict:
    r"""
        **Autogenerated function**


        Returns a description of the cluster operation specified by the ARN.


        Args:
            cluster_operation_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the MSK cluster operation.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.operation.describe(
                    ctx, cluster_operation_arn=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.operation.describe cluster_operation_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="describe_cluster_operation",
        op_kwargs={"ClusterOperationArn": cluster_operation_arn},
    )


async def list_all(
    hub, ctx, cluster_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of all the operations that have been performed on the specified MSK cluster.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .
            max_results(int, optional):
    The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.
    . Defaults to None.
            next_token(str, optional):
    The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response.
                To get the next batch, provide this token in your next request.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.operation.list_all(ctx, cluster_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.operation.list_all cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_cluster_operations",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "primary_task_set"


async def update(hub, ctx, cluster: str, service: str, primary_task_set: str) -> Dict:
    r"""
    **Autogenerated function**

    Modifies which task set in a service is the primary task set. Any parameters that are updated on the primary task set in a service will transition to the service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
        service(str): The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
        primary_task_set(str): The short name or full Amazon Resource Name (ARN) of the task set to set as the primary task set in the deployment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.service.primary_task_set_.update(
                ctx, cluster=value, service=value, primary_task_set=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.service.primary_task_set.update cluster=value, service=value, primary_task_set=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_service_primary_task_set",
        op_kwargs={
            "cluster": cluster,
            "service": service,
            "primaryTaskSet": primary_task_set,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    environment_id: str = None,
    environment_name: str = None,
    next_token: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists an environment's completed and failed managed actions.

    Args:
        environment_id(str, optional): The environment ID of the target environment. Defaults to None.
        environment_name(str, optional): The name of the target environment. Defaults to None.
        next_token(str, optional): The pagination token returned by a previous request. Defaults to None.
        max_items(int, optional): The maximum number of items to return for a single request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.managed_action.history.describe(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.managed_action.history.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_environment_managed_action_history",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "NextToken": next_token,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    name: str,
    permission_type: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the permissions for a Amazon Web Services Systems Manager document (SSM document). If you created the document, you are the owner. If a document is shared, it can either be shared privately (by specifying a user's account ID) or publicly (All).

    Args:
        name(str): The name of the document for which you are the owner.
        permission_type(str): The permission type for the document. The permission type can be Share.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.permission.describe(
                ctx, name=value, permission_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.permission.describe name=value, permission_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_document_permission",
        op_kwargs={
            "Name": name,
            "PermissionType": permission_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    name: str,
    permission_type: str,
    account_ids_to_add: List = None,
    account_ids_to_remove: List = None,
    shared_document_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Shares a Amazon Web Services Systems Manager document (SSM document)publicly or privately. If you share a document privately, you must specify the Amazon Web Services user account IDs for those people who can use the document. If you share a document publicly, you must specify All as the account ID.

    Args:
        name(str): The name of the document that you want to share.
        permission_type(str): The permission type for the document. The permission type can be Share.
        account_ids_to_add(List, optional): The Amazon Web Services user accounts that should have access to the document. The account IDs can either be a group of account IDs or All. Defaults to None.
        account_ids_to_remove(List, optional): The Amazon Web Services user accounts that should no longer have access to the document. The Amazon Web Services user account can either be a group of account IDs or All. This action has a higher priority than AccountIdsToAdd. If you specify an account ID to add and the same ID to remove, the system removes access to the document. Defaults to None.
        shared_document_version(str, optional): (Optional) The version of the document to share. If it isn't specified, the system choose the Default version to share. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.permission.modify(
                ctx, name=value, permission_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.permission.modify name=value, permission_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="modify_document_permission",
        op_kwargs={
            "Name": name,
            "PermissionType": permission_type,
            "AccountIdsToAdd": account_ids_to_add,
            "AccountIdsToRemove": account_ids_to_remove,
            "SharedDocumentVersion": shared_document_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the name and additional information about a celebrity based on his or her Amazon Rekognition ID. The additional information is returned as an array of URLs. If there is no additional information about the celebrity, this list is empty. For more information, see Recognizing Celebrities in an Image in the Amazon Rekognition Developer Guide. This operation requires permissions to perform the rekognition:GetCelebrityInfo action.

    Args:
        id_(str): The ID for the celebrity. You get the celebrity ID from a call to the RecognizeCelebrities operation, which recognizes celebrities in an image. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.celebrity.info.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.celebrity.info.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_celebrity_info",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, name: str, recipe_versions: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more versions of a recipe at a time. The entire request will be rejected if:   The recipe does not exist.   There is an invalid version identifier in the list of versions.   The version list is empty.   The version list size exceeds 50.   The version list contains duplicate entries.   The request will complete successfully, but with partial failures, if:   A version does not exist.   A version is being used by a job.   You specify LATEST_WORKING, but it's being used by a project.   The version fails to be deleted.   The LATEST_WORKING version will only be deleted if the recipe has no other versions. If you try to delete LATEST_WORKING while other versions exist (or if they can't be deleted), then LATEST_WORKING will be listed as partial failure in the response.

    Args:
        name(str): The name of the recipe whose versions are to be deleted.
        recipe_versions(List): An array of version identifiers, for the recipe versions to be deleted. You can specify numeric versions (X.Y) or LATEST_WORKING. LATEST_PUBLISHED is not supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.delete_recipe_version.batch(
                ctx, name=value, recipe_versions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.delete_recipe_version.batch name=value, recipe_versions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="batch_delete_recipe_version",
        op_kwargs={"Name": name, "RecipeVersions": recipe_versions},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, recovery_group_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a Recovery Group.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.
        recovery_group_name(str): The name of the RecoveryGroup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.readiness_summary.get(
                ctx, recovery_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.readiness_summary.get recovery_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="get_recovery_group_readiness_summary",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "RecoveryGroupName": recovery_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    mesh_name: str,
    spec: Dict,
    virtual_router_name: str,
    client_token: str = None,
    mesh_owner: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a virtual router within a service mesh. Specify a listener for any inbound traffic that your virtual router receives. Create a virtual router for each protocol and port that you need to route. Virtual routers handle traffic for one or more virtual services within your mesh. After you create your virtual router, create and associate routes for your virtual router that direct incoming requests to different virtual nodes. For more information about virtual routers, see Virtual routers.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh to create the virtual router in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then the account that you specify must share the mesh with your account before you can create the resource in the service mesh. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The virtual router specification to apply.
        tags(List, optional): Optional metadata that you can apply to the virtual router to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.
        virtual_router_name(str): The name to use for the virtual router.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.router.create(
                ctx, mesh_name=value, spec=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.router.create mesh_name=value, spec=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="create_virtual_router",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "tags": tags,
            "virtualRouterName": virtual_router_name,
        },
    )


async def delete(
    hub, ctx, mesh_name: str, virtual_router_name: str, mesh_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing virtual router. You must delete any routes associated with the virtual router before you can delete the router itself.

    Args:
        mesh_name(str): The name of the service mesh to delete the virtual router in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_router_name(str): The name of the virtual router to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.router.delete(
                ctx, mesh_name=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.router.delete mesh_name=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="delete_virtual_router",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualRouterName": virtual_router_name,
        },
    )


async def describe(
    hub, ctx, mesh_name: str, virtual_router_name: str, mesh_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing virtual router.

    Args:
        mesh_name(str): The name of the service mesh that the virtual router resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_router_name(str): The name of the virtual router to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.router.describe(
                ctx, mesh_name=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.router.describe mesh_name=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="describe_virtual_router",
        op_kwargs={
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualRouterName": virtual_router_name,
        },
    )


async def list_all(
    hub,
    ctx,
    mesh_name: str,
    limit: int = None,
    mesh_owner: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing virtual routers in a service mesh.

    Args:
        limit(int, optional): The maximum number of results returned by ListVirtualRouters in paginated output. When you use this parameter, ListVirtualRouters returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListVirtualRouters request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListVirtualRouters returns up to 100 results and a nextToken value if applicable. Defaults to None.
        mesh_name(str): The name of the service mesh to list virtual routers in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListVirtualRouters request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.router.list_all(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.router.list_all mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_virtual_routers",
        op_kwargs={
            "limit": limit,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    mesh_name: str,
    spec: Dict,
    virtual_router_name: str,
    client_token: str = None,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing virtual router in a specified service mesh.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh that the virtual router resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The new virtual router specification to apply. This overwrites the existing data.
        virtual_router_name(str): The name of the virtual router to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.virtual.router.update(
                ctx, mesh_name=value, spec=value, virtual_router_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.virtual.router.update mesh_name=value, spec=value, virtual_router_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="update_virtual_router",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "virtualRouterName": virtual_router_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, aws_region: str, name: str, endpoints: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates a SIP media application.

    Args:
        aws_region(str): The AWS Region assigned to the SIP media application.
        name(str): The SIP media application name.
        endpoints(List): List of endpoints (Lambda Amazon Resource Names) specified for the SIP media application. Currently, only one endpoint is supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.init.create(
                ctx, aws_region=value, name=value, endpoints=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.init.create aws_region=value, name=value, endpoints=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_sip_media_application",
        op_kwargs={"AwsRegion": aws_region, "Name": name, "Endpoints": endpoints},
    )


async def delete(hub, ctx, sip_media_application_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a SIP media application.

    Args:
        sip_media_application_id(str): The SIP media application ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.init.delete(
                ctx, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.init.delete sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_sip_media_application",
        op_kwargs={"SipMediaApplicationId": sip_media_application_id},
    )


async def get(hub, ctx, sip_media_application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.

    Args:
        sip_media_application_id(str): The SIP media application ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.init.get(
                ctx, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.init.get sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_sip_media_application",
        op_kwargs={"SipMediaApplicationId": sip_media_application_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the SIP media applications under the administrator's AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to 100. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_sip_media_applications",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, sip_media_application_id: str, name: str = None, endpoints: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of the specified SIP media application.

    Args:
        sip_media_application_id(str): The SIP media application ID.
        name(str, optional): The new name for the specified SIP media application. Defaults to None.
        endpoints(List, optional): The new set of endpoints for the specified SIP media application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.init.update(
                ctx, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.init.update sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_sip_media_application",
        op_kwargs={
            "SipMediaApplicationId": sip_media_application_id,
            "Name": name,
            "Endpoints": endpoints,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, task_token: str, error: str = None, cause: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Used by activity workers and task states using the callback pattern to report that the task identified by the taskToken failed.

    Args:
        task_token(str): The token that represents this task. Task tokens are generated by Step Functions when tasks are assigned to a worker, or in the context object when a workflow enters a task state. See GetActivityTaskOutput$taskToken.
        error(str, optional): The error code of the failure. Defaults to None.
        cause(str, optional): A more detailed explanation of the cause of the failure. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.task.failure.send(ctx, task_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.task.failure.send task_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="send_task_failure",
        op_kwargs={"taskToken": task_token, "error": error, "cause": cause},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Deletes the password policy for the account. There are no parameters.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.password_policy.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.password_policy.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_account_password_policy",
        op_kwargs={},
    )


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the password policy for the account. This tells you the complexity requirements and mandatory rotation periods for the IAM user passwords in your account. For more information about using a password policy, see Managing an IAM password policy.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.password_policy.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.password_policy.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iam", operation="get_account_password_policy", op_kwargs={}
    )


async def update(
    hub,
    ctx,
    minimum_password_length: int = None,
    require_symbols: bool = None,
    require_numbers: bool = None,
    require_uppercase_characters: bool = None,
    require_lowercase_characters: bool = None,
    allow_users_to_change_password: bool = None,
    max_password_age: int = None,
    password_reuse_prevention: int = None,
    hard_expiry: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the password policy settings for the account.    This operation does not support partial updates. No parameters are required, but if you do not specify a parameter, that parameter's value reverts to its default value. See the Request Parameters section for each parameter's default value. Also note that some parameters do not allow the default parameter to be explicitly set. Instead, to invoke the default value, do not include that parameter when you invoke the operation.     For more information about using a password policy, see Managing an IAM password policy in the IAM User Guide.

    Args:
        minimum_password_length(int, optional): The minimum number of characters allowed in an IAM user password. If you do not specify a value for this parameter, then the operation uses the default value of 6. Defaults to None.
        require_symbols(bool, optional): Specifies whether IAM user passwords must contain at least one of the following non-alphanumeric characters: ! @ # $ % ^ & * ( ) _ + - = [ ] { } | ' If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one symbol character. Defaults to None.
        require_numbers(bool, optional): Specifies whether IAM user passwords must contain at least one numeric character (0 to 9). If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one numeric character. Defaults to None.
        require_uppercase_characters(bool, optional): Specifies whether IAM user passwords must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one uppercase character. Defaults to None.
        require_lowercase_characters(bool, optional): Specifies whether IAM user passwords must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one lowercase character. Defaults to None.
        allow_users_to_change_password(bool, optional):  Allows all IAM users in your account to use the Management Console to change their own passwords. For more information, see Letting IAM users change their own passwords in the IAM User Guide. If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users in the account do not automatically have permissions to change their own password. Defaults to None.
        max_password_age(int, optional): The number of days that an IAM user password is valid. If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM user passwords never expire. Defaults to None.
        password_reuse_prevention(int, optional): Specifies the number of previous passwords that IAM users are prevented from reusing. If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM users are not prevented from reusing previous passwords. Defaults to None.
        hard_expiry(bool, optional): Prevents IAM users from setting a new password after their password has expired. The IAM user cannot be accessed until an administrator resets the password. If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users can change their passwords after they expire and continue to sign in as the user. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.password_policy.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.password_policy.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_account_password_policy",
        op_kwargs={
            "MinimumPasswordLength": minimum_password_length,
            "RequireSymbols": require_symbols,
            "RequireNumbers": require_numbers,
            "RequireUppercaseCharacters": require_uppercase_characters,
            "RequireLowercaseCharacters": require_lowercase_characters,
            "AllowUsersToChangePassword": allow_users_to_change_password,
            "MaxPasswordAge": max_password_age,
            "PasswordReusePrevention": password_reuse_prevention,
            "HardExpiry": hard_expiry,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(hub, ctx, user_name: str, policy_arn: str) -> None:
    r"""
    **Autogenerated function**

    Attaches the specified managed policy to the specified user. You use this operation to attach a managed policy to a user. To embed an inline policy in a user, use PutUserPolicy. As a best practice, you can validate your IAM policies. To learn more, see Validating IAM policies in the IAM User Guide. For more information about policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        user_name(str): The name (friendly name, not ARN) of the IAM user to attach the policy to. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy you want to attach. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.attach(ctx, user_name=value, policy_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.attach user_name=value, policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="attach_user_policy",
        op_kwargs={"UserName": user_name, "PolicyArn": policy_arn},
    )


async def delete(hub, ctx, user_name: str, policy_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified inline policy that is embedded in the specified IAM user. A user can also have managed policies attached to it. To detach a managed policy from a user, use DetachUserPolicy. For more information about policies, refer to Managed policies and inline policies in the IAM User Guide.

    Args:
        user_name(str): The name (friendly name, not ARN) identifying the user that the policy is embedded in. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_name(str): The name identifying the policy document to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.delete(ctx, user_name=value, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.delete user_name=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_user_policy",
        op_kwargs={"UserName": user_name, "PolicyName": policy_name},
    )


async def detach(hub, ctx, user_name: str, policy_arn: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified managed policy from the specified user. A user can also have inline policies embedded with it. To delete an inline policy, use DeleteUserPolicy. For information about policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        user_name(str): The name (friendly name, not ARN) of the IAM user to detach the policy from. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy you want to detach. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.detach(ctx, user_name=value, policy_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.detach user_name=value, policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="detach_user_policy",
        op_kwargs={"UserName": user_name, "PolicyArn": policy_arn},
    )


async def get(hub, ctx, user_name: str, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified inline policy document that is embedded in the specified IAM user.  Policies returned by this operation are URL-encoded compliant with RFC 3986. You can use a URL decoding method to convert the policy back to plain JSON text. For example, if you use Java, you can use the decode method of the java.net.URLDecoder utility class in the Java SDK. Other languages and SDKs provide similar functionality.  An IAM user can also have managed policies attached to it. To retrieve a managed policy document that is attached to a user, use GetPolicy to determine the policy's default version. Then use GetPolicyVersion to retrieve the policy document. For more information about policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        user_name(str): The name of the user who the policy is associated with. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_name(str): The name of the policy document to get. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.get(ctx, user_name=value, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.get user_name=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_user_policy",
        op_kwargs={"UserName": user_name, "PolicyName": policy_name},
    )


async def list_all(
    hub, ctx, user_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the names of the inline policies embedded in the specified IAM user. An IAM user can also have managed policies attached to it. To list the managed policies that are attached to a user, use ListAttachedUserPolicies. For more information about policies, see Managed policies and inline policies in the IAM User Guide. You can paginate the results using the MaxItems and Marker parameters. If there are no inline policies embedded with the specified user, the operation returns an empty list.

    Args:
        user_name(str): The name of the user to list policies for. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.list_all(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.list_all user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_user_policies",
        op_kwargs={"UserName": user_name, "Marker": marker, "MaxItems": max_items},
    )


async def put(hub, ctx, user_name: str, policy_name: str, policy_document: str) -> None:
    r"""
    **Autogenerated function**

    Adds or updates an inline policy document that is embedded in the specified IAM user. An IAM user can also have a managed policy attached to it. To attach a managed policy to a user, use AttachUserPolicy. To create a new managed policy, use CreatePolicy. For information about policies, see Managed policies and inline policies in the IAM User Guide. For information about the maximum number of inline policies that you can embed in a user, see IAM and STS quotas in the IAM User Guide.  Because policy documents can be large, you should use POST rather than GET when calling PutUserPolicy. For general information about using the Query API with IAM, see Making query requests in the IAM User Guide.

    Args:
        user_name(str): The name of the user to associate the policy with. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_name(str): The name of the policy document. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        policy_document(str): The policy document. You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.policy.put(
                ctx, user_name=value, policy_name=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.policy.put user_name=value, policy_name=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="put_user_policy",
        op_kwargs={
            "UserName": user_name,
            "PolicyName": policy_name,
            "PolicyDocument": policy_document,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub, ctx, command_id: str, instance_id: str, plugin_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about command execution for an invocation or plugin.  GetCommandInvocation only gives the execution status of a plugin in a document. To get the command execution status on a specific instance, use ListCommandInvocations. To get the command execution status across instances, use ListCommands.

    Args:
        command_id(str): (Required) The parent command ID of the invocation plugin.
        instance_id(str): (Required) The ID of the managed instance targeted by the command. A managed instance can be an Amazon Elastic Compute Cloud (Amazon EC2) instance or an instance in your hybrid environment that is configured for Amazon Web Services Systems Manager.
        plugin_name(str, optional): The name of the plugin for which you want detailed results. If the document contains only one plugin, you can omit the name and details for that plugin. If the document contains more than one plugin, you must specify the name of the plugin for which you want to view details. Plugin names are also referred to as step names in Systems Manager documents (SSM documents). For example, aws:RunShellScript is a plugin. To find the PluginName, check the document content and find the name of the plugin. Alternatively, use ListCommandInvocations with the CommandId and Details parameters. The PluginName is the Name attribute of the CommandPlugin object in the CommandPlugins list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.command.invocation.get(
                ctx, command_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.command.invocation.get command_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_command_invocation",
        op_kwargs={
            "CommandId": command_id,
            "InstanceId": instance_id,
            "PluginName": plugin_name,
        },
    )


async def list_all(
    hub,
    ctx,
    command_id: str = None,
    instance_id: str = None,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
    details: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    An invocation is copy of a command sent to a specific instance. A command can apply to one or more instances. A command invocation applies to one instance. For example, if a user runs SendCommand against three instances, then a command invocation is created for each requested instance ID. ListCommandInvocations provide status about command execution.

    Args:
        command_id(str, optional): (Optional) The invocations for a specific command ID. Defaults to None.
        instance_id(str, optional): (Optional) The command execution details for a specific instance ID. Defaults to None.
        max_results(int, optional): (Optional) The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): (Optional) The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        filters(List, optional): (Optional) One or more filters. Use a filter to return a more specific list of results. Defaults to None.
        details(bool, optional): (Optional) If set this returns the response of the command executions and any command output. The default value is false. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.command.invocation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.command.invocation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_command_invocations",
        op_kwargs={
            "CommandId": command_id,
            "InstanceId": instance_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
            "Details": details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, analyzer_arn: str, configurations: Dict, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an access preview that allows you to preview Access Analyzer findings for your resource before deploying resource permissions.

    Args:
        analyzer_arn(str): The ARN of the account analyzer used to generate the access preview. You can only create an access preview for analyzers with an Account type and Active status.
        client_token(str, optional): A client token. Defaults to None.
        configurations(Dict): Access control configuration for your resource that is used to generate the access preview. The access preview includes findings for external access allowed to the resource with the proposed access control configuration. The configuration must contain exactly one element.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.access_preview.init.create(
                ctx, analyzer_arn=value, configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.access_preview.init.create analyzer_arn=value, configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="create_access_preview",
        op_kwargs={
            "analyzerArn": analyzer_arn,
            "clientToken": client_token,
            "configurations": configurations,
        },
    )


async def get(hub, ctx, access_preview_id: str, analyzer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an access preview for the specified analyzer.

    Args:
        access_preview_id(str): The unique ID for the access preview.
        analyzer_arn(str): The ARN of the analyzer used to generate the access preview.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.access_preview.init.get(
                ctx, access_preview_id=value, analyzer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.access_preview.init.get access_preview_id=value, analyzer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="get_access_preview",
        op_kwargs={"accessPreviewId": access_preview_id, "analyzerArn": analyzer_arn},
    )


async def list_all(
    hub, ctx, analyzer_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of access previews for the specified analyzer.

    Args:
        analyzer_arn(str): The ARN of the analyzer used to generate the access preview.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.access_preview.init.list_all(
                ctx, analyzer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.access_preview.init.list_all analyzer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="list_access_previews",
        op_kwargs={
            "analyzerArn": analyzer_arn,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    activity_ids: List = None,
    auto_scaling_group_name: str = None,
    include_deleted_groups: bool = None,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the scaling activities in the account and Region. When scaling events occur, you see a record of the scaling activity in the scaling activities. For more information, see Verifying a scaling activity for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide. If the scaling event succeeds, the value of the StatusCode element in the response is Successful. If an attempt to launch instances failed, the StatusCode value is Failed or Cancelled and the StatusMessage element in the response indicates the cause of the failure. For help interpreting the StatusMessage, see Troubleshooting Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        activity_ids(List, optional): The activity IDs of the desired scaling activities. If you omit this parameter, all activities for the past six weeks are described. If unknown activities are requested, they are ignored with no error. If you specify an Auto Scaling group, the results are limited to that group. Array Members: Maximum number of 50 IDs. Defaults to None.
        auto_scaling_group_name(str, optional): The name of the Auto Scaling group. Defaults to None.
        include_deleted_groups(bool, optional): Indicates whether to include scaling activity from deleted Auto Scaling groups. Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 100 and the maximum value is 100. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.scaling.activity.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.scaling.activity.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_scaling_activities",
        op_kwargs={
            "ActivityIds": activity_ids,
            "AutoScalingGroupName": auto_scaling_group_name,
            "IncludeDeletedGroups": include_deleted_groups,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new behavior graph for the calling account, and sets that account as the administrator account. This operation is called by the account that is enabling Detective. Before you try to enable Detective, make sure that your account has been enrolled in Amazon GuardDuty for at least 48 hours. If you do not meet this requirement, you cannot enable Detective. If you do meet the GuardDuty prerequisite, then when you make the request to enable Detective, it checks whether your data volume is within the Detective quota. If it exceeds the quota, then you cannot enable Detective.  The operation also enables Detective for the calling account in the currently selected Region. It returns the ARN of the new behavior graph.  CreateGraph triggers a process to create the corresponding data tables for the new behavior graph. An account can only be the administrator account for one behavior graph within a Region. If the same account calls CreateGraph with the same administrator account, it always returns the same behavior graph ARN. It does not create a new behavior graph.

    Args:
        tags(Dict, optional): The tags to assign to the new behavior graph. You can add up to 50 tags. For each tag, you provide the tag key and the tag value. Each tag key can contain up to 128 characters. Each tag value can contain up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.graph.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.graph.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="create_graph",
        op_kwargs={"Tags": tags},
    )


async def delete(hub, ctx, graph_arn: str) -> None:
    r"""
    **Autogenerated function**

    Disables the specified behavior graph and queues it to be deleted. This operation removes the graph from each member account's list of behavior graphs.  DeleteGraph can only be called by the administrator account for a behavior graph.

    Args:
        graph_arn(str): The ARN of the behavior graph to disable.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.graph.delete(ctx, graph_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.graph.delete graph_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="delete_graph",
        op_kwargs={"GraphArn": graph_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of behavior graphs that the calling account is an administrator account of. This operation can only be called by an administrator account. Because an account can currently only be the administrator of one behavior graph within a Region, the results always contain a single behavior graph.

    Args:
        next_token(str, optional): For requests to get the next page of results, the pagination token that was returned with the previous set of results. The initial request does not include a pagination token. Defaults to None.
        max_results(int, optional): The maximum number of graphs to return at a time. The total must be less than the overall limit on the number of results to return, which is currently 200. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.graph.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.graph.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="list_graphs",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).

    Args:
        resource_id(str): The ID of the VPC from Amazon VPC that the configuration is for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.config.get(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.config.get resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_firewall_config",
        op_kwargs={"ResourceId": resource_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the firewall configurations that you have defined. DNS Firewall uses the configurations to manage firewall behavior for your VPCs.  A single call might return only a partial list of the configurations. For information, see MaxResults.

    Args:
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_configs",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, resource_id: str, firewall_fail_open: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC).

    Args:
        resource_id(str): The ID of the VPC that the configuration is for.
        firewall_fail_open(str): Determines how Route 53 Resolver handles queries during failures, for example when all traffic that is sent to DNS Firewall fails to receive a reply.    By default, fail open is disabled, which means the failure mode is closed. This approach favors security over availability. DNS Firewall blocks queries that it is unable to evaluate properly.    If you enable this option, the failure mode is open. This approach favors availability over security. DNS Firewall allows queries to proceed if it is unable to properly evaluate them.    This behavior is only enforced for VPCs that have at least one DNS Firewall rule group association. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.config.update(
                ctx, resource_id=value, firewall_fail_open=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.config.update resource_id=value, firewall_fail_open=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_firewall_config",
        op_kwargs={"ResourceId": resource_id, "FirewallFailOpen": firewall_fail_open},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, alias: str = None, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new AMP workspace.

    Args:
        alias(str, optional): An optional user-assigned alias for this workspace. This alias is for user reference and does not need to be unique. Defaults to None.
        client_token(str, optional): Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amp_workspace.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amp_workspace.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amp",
        operation="create_workspace",
        op_kwargs={"alias": alias, "clientToken": client_token},
    )


async def delete(hub, ctx, workspace_id: str, client_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes an AMP workspace.

    Args:
        client_token(str, optional): Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request. Defaults to None.
        workspace_id(str): The ID of the workspace to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amp_workspace.init.delete(ctx, workspace_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amp_workspace.init.delete workspace_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amp",
        operation="delete_workspace",
        op_kwargs={"clientToken": client_token, "workspaceId": workspace_id},
    )


async def describe(hub, ctx, workspace_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing AMP workspace.

    Args:
        workspace_id(str): The ID of the workspace to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amp_workspace.init.describe(ctx, workspace_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amp_workspace.init.describe workspace_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amp",
        operation="describe_workspace",
        op_kwargs={"workspaceId": workspace_id},
    )


async def list_all(
    hub, ctx, alias: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all AMP workspaces, including workspaces being created or deleted.

    Args:
        alias(str, optional): Optional filter for workspace alias. Only the workspaces with aliases that begin with this value will be returned. Defaults to None.
        max_results(int, optional): Maximum results to return in response (default=100, maximum=1000). Defaults to None.
        next_token(str, optional): Pagination token to request the next page in a paginated list. This token is obtained from the output of the previous ListWorkspaces request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amp_workspace.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amp_workspace.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amp",
        operation="list_workspaces",
        op_kwargs={"alias": alias, "maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    resource_share_arn: str,
    permission_arn: str,
    replace: bool = None,
    client_token: str = None,
    permission_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a permission with a resource share.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        permission_arn(str): The Amazon Resource Name (ARN) of the AWS RAM permissions to associate with the resource share.
        replace(bool, optional): Indicates whether the permission should replace the permissions that are currently associated with the resource share. Use true to replace the current permissions. Use false to add the permission to the current permission. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        permission_version(int, optional): The version of the AWS RAM permissions to associate with the resource share. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.permission.associate(
                ctx, resource_share_arn=value, permission_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.permission.associate resource_share_arn=value, permission_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="associate_resource_share_permission",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "permissionArn": permission_arn,
            "replace": replace,
            "clientToken": client_token,
            "permissionVersion": permission_version,
        },
    )


async def disassociate(
    hub, ctx, resource_share_arn: str, permission_arn: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an AWS RAM permission from a resource share.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        permission_arn(str): The ARN of the permission to disassociate from the resource share.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.permission.disassociate(
                ctx, resource_share_arn=value, permission_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.permission.disassociate resource_share_arn=value, permission_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="disassociate_resource_share_permission",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "permissionArn": permission_arn,
            "clientToken": client_token,
        },
    )


async def list_all(
    hub, ctx, resource_share_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AWS RAM permissions that are associated with a resource share.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.permission.list_all(
                ctx, resource_share_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.permission.list_all resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="list_resource_share_permissions",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "checker_ip_range"


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Route 53 does not perform authorization for this API because it retrieves information that is already available to the public.   GetCheckerIpRanges still works, but we recommend that you download ip-ranges.json, which includes IP address ranges for all Amazon Web Services services. For more information, see IP Address Ranges of Amazon Route 53 Servers in the Amazon Route 53 Developer Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.checker_ip_range_.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.checker_ip_range.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="route53", operation="get_checker_ip_ranges", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, satellite_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a satellite.

    Args:
        satellite_id(str): UUID of a satellite.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.satellite.get(ctx, satellite_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.satellite.get satellite_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="get_satellite",
        op_kwargs={"satelliteId": satellite_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of satellites.

    Args:
        max_results(int, optional): Maximum number of satellites returned. Defaults to None.
        next_token(str, optional): Next token that can be supplied in the next call to get the next page of satellites. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.satellite.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.satellite.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_satellites",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, directory_id: str, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables alternative client authentication methods for the specified directory.

    Args:
        directory_id(str): The identifier of the directory .
        type_(str): The type of client authentication to disable. Currently, only the parameter, SmartCard is supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.client_authentication.disable(
                ctx, directory_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.client_authentication.disable directory_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="disable_client_authentication",
        op_kwargs={"DirectoryId": directory_id, "Type": type_},
    )


async def enable(hub, ctx, directory_id: str, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables alternative client authentication methods for the specified directory.

    Args:
        directory_id(str): The identifier of the specified directory. .
        type_(str): The type of client authentication to enable. Currently only the value SmartCard is supported. Smart card authentication in AD Connector requires that you enable Kerberos Constrained Delegation for the Service User to the LDAP service in the on-premises AD. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.client_authentication.enable(
                ctx, directory_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.client_authentication.enable directory_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="enable_client_authentication",
        op_kwargs={"DirectoryId": directory_id, "Type": type_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_proxy_name: str,
    db_proxy_endpoint_name: str,
    vpc_subnet_ids: List,
    vpc_security_group_ids: List = None,
    target_role: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a DBProxyEndpoint. Only applies to proxies that are associated with Aurora DB clusters. You can use DB proxy endpoints to specify read/write or read-only access to the DB cluster. You can also use DB proxy endpoints to access a DB proxy through a different VPC than the proxy's default VPC.

    Args:
        db_proxy_name(str): The name of the DB proxy associated with the DB proxy endpoint that you create.
        db_proxy_endpoint_name(str): The name of the DB proxy endpoint to create.
        vpc_subnet_ids(List): The VPC subnet IDs for the DB proxy endpoint that you create. You can specify a different set of subnet IDs than for the original DB proxy.
        vpc_security_group_ids(List, optional): The VPC security group IDs for the DB proxy endpoint that you create. You can specify a different set of security group IDs than for the original DB proxy. The default is the default security group for the VPC. Defaults to None.
        target_role(str, optional): A value that indicates whether the DB proxy endpoint can be used for read/write or read-only operations. The default is READ_WRITE. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.endpoint.create(
                ctx, db_proxy_name=value, db_proxy_endpoint_name=value, vpc_subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.endpoint.create db_proxy_name=value, db_proxy_endpoint_name=value, vpc_subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_proxy_endpoint",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "DBProxyEndpointName": db_proxy_endpoint_name,
            "VpcSubnetIds": vpc_subnet_ids,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "TargetRole": target_role,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_proxy_endpoint_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a DBProxyEndpoint. Doing so removes the ability to access the DB proxy using the endpoint that you defined. The endpoint that you delete might have provided capabilities such as read/write or read-only operations, or using a different VPC than the DB proxy's default VPC.

    Args:
        db_proxy_endpoint_name(str): The name of the DB proxy endpoint to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.endpoint.delete(ctx, db_proxy_endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.endpoint.delete db_proxy_endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_proxy_endpoint",
        op_kwargs={"DBProxyEndpointName": db_proxy_endpoint_name},
    )


async def describe_all(
    hub,
    ctx,
    db_proxy_name: str = None,
    db_proxy_endpoint_name: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DB proxy endpoints.

    Args:
        db_proxy_name(str, optional): The name of the DB proxy whose endpoints you want to describe. If you omit this parameter, the output includes information about all DB proxy endpoints associated with all your DB proxies. Defaults to None.
        db_proxy_endpoint_name(str, optional): The name of a DB proxy endpoint to describe. If you omit this parameter, the output includes information about all DB proxy endpoints associated with the specified proxy. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.endpoint.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.endpoint.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_proxy_endpoints",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "DBProxyEndpointName": db_proxy_endpoint_name,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def modify(
    hub,
    ctx,
    db_proxy_endpoint_name: str,
    new_db_proxy_endpoint_name: str = None,
    vpc_security_group_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the settings for an existing DB proxy endpoint.

    Args:
        db_proxy_endpoint_name(str): The name of the DB proxy sociated with the DB proxy endpoint that you want to modify.
        new_db_proxy_endpoint_name(str, optional): The new identifier for the DBProxyEndpoint. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens. Defaults to None.
        vpc_security_group_ids(List, optional): The VPC security group IDs for the DB proxy endpoint. When the DB proxy endpoint uses a different VPC than the original proxy, you also specify a different set of security group IDs than for the original proxy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.endpoint.modify(ctx, db_proxy_endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.endpoint.modify db_proxy_endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_db_proxy_endpoint",
        op_kwargs={
            "DBProxyEndpointName": db_proxy_endpoint_name,
            "NewDBProxyEndpointName": new_db_proxy_endpoint_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, core_device_thing_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Greengrass core device, which is an IoT thing. This operation removes the core device from the list of core devices. This operation doesn't delete the IoT thing. For more information about how to delete the IoT thing, see DeleteThing in the IoT API Reference.

    Args:
        core_device_thing_name(str): The name of the core device. This is also the name of the IoT thing.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.core_device.delete(
                ctx, core_device_thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.core_device.delete core_device_thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="delete_core_device",
        op_kwargs={"coreDeviceThingName": core_device_thing_name},
    )


async def get(hub, ctx, core_device_thing_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for a Greengrass core device.

    Args:
        core_device_thing_name(str): The name of the core device. This is also the name of the IoT thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.core_device.get(ctx, core_device_thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.core_device.get core_device_thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="get_core_device",
        op_kwargs={"coreDeviceThingName": core_device_thing_name},
    )


async def list_all(
    hub,
    ctx,
    thing_group_arn: str = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of Greengrass core devices.

    Args:
        thing_group_arn(str, optional): The ARN of the IoT thing group by which to filter. If you specify this parameter, the list includes only core devices that are members of this thing group. Defaults to None.
        status(str, optional): The core device status by which to filter. If you specify this parameter, the list includes only core devices that have this status. Choose one of the following options:    HEALTHY – The IoT Greengrass Core software and all components run on the core device without issue.    UNHEALTHY – The IoT Greengrass Core software or a component is in a failed state on the core device.  . Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per paginated request. Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.core_device.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.core_device.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="list_core_devices",
        op_kwargs={
            "thingGroupArn": thing_group_arn,
            "status": status,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    instance_type: str,
    image_name: str = None,
    image_arn: str = None,
    description: str = None,
    display_name: str = None,
    vpc_config: Dict = None,
    iam_role_arn: str = None,
    enable_default_internet_access: bool = None,
    domain_join_info: Dict = None,
    appstream_agent_version: str = None,
    tags: Dict = None,
    access_endpoints: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an image builder. An image builder is a virtual machine that is used to create an image. The initial state of the builder is PENDING. When it is ready, the state is RUNNING.

    Args:
        name(str): A unique name for the image builder.
        image_name(str, optional): The name of the image used to create the image builder. Defaults to None.
        image_arn(str, optional): The ARN of the public, private, or shared image to use. Defaults to None.
        instance_type(str): The instance type to use when launching the image builder. The following instance types are available:   stream.standard.small   stream.standard.medium   stream.standard.large   stream.compute.large   stream.compute.xlarge   stream.compute.2xlarge   stream.compute.4xlarge   stream.compute.8xlarge   stream.memory.large   stream.memory.xlarge   stream.memory.2xlarge   stream.memory.4xlarge   stream.memory.8xlarge   stream.memory.z1d.large   stream.memory.z1d.xlarge   stream.memory.z1d.2xlarge   stream.memory.z1d.3xlarge   stream.memory.z1d.6xlarge   stream.memory.z1d.12xlarge   stream.graphics-design.large   stream.graphics-design.xlarge   stream.graphics-design.2xlarge   stream.graphics-design.4xlarge   stream.graphics-desktop.2xlarge   stream.graphics.g4dn.xlarge   stream.graphics.g4dn.2xlarge   stream.graphics.g4dn.4xlarge   stream.graphics.g4dn.8xlarge   stream.graphics.g4dn.12xlarge   stream.graphics.g4dn.16xlarge   stream.graphics-pro.4xlarge   stream.graphics-pro.8xlarge   stream.graphics-pro.16xlarge  .
        description(str, optional): The description to display. Defaults to None.
        display_name(str, optional): The image builder name to display. Defaults to None.
        vpc_config(Dict, optional): The VPC configuration for the image builder. You can specify only one subnet. Defaults to None.
        iam_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role to apply to the image builder. To assume a role, the image builder calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. AppStream 2.0 retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance. For more information, see Using an IAM Role to Grant Permissions to Applications and Scripts Running on AppStream 2.0 Streaming Instances in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        enable_default_internet_access(bool, optional): Enables or disables default internet access for the image builder. Defaults to None.
        domain_join_info(Dict, optional): The name of the directory and organizational unit (OU) to use to join the image builder to a Microsoft Active Directory domain. . Defaults to None.
        appstream_agent_version(str, optional): The version of the AppStream 2.0 agent to use for this image builder. To use the latest version of the AppStream 2.0 agent, specify [LATEST]. . Defaults to None.
        tags(Dict, optional): The tags to associate with the image builder. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.  Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:  _ . : / = + \ - @ If you do not specify a value, the value is set to an empty string. For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        access_endpoints(List, optional): The list of interface VPC endpoint (interface endpoint) objects. Administrators can connect to the image builder only through the specified endpoints. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.init.create(
                ctx, name=value, instance_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.init.create name=value, instance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_image_builder",
        op_kwargs={
            "Name": name,
            "ImageName": image_name,
            "ImageArn": image_arn,
            "InstanceType": instance_type,
            "Description": description,
            "DisplayName": display_name,
            "VpcConfig": vpc_config,
            "IamRoleArn": iam_role_arn,
            "EnableDefaultInternetAccess": enable_default_internet_access,
            "DomainJoinInfo": domain_join_info,
            "AppstreamAgentVersion": appstream_agent_version,
            "Tags": tags,
            "AccessEndpoints": access_endpoints,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified image builder and releases the capacity.

    Args:
        name(str): The name of the image builder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_image_builder",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub, ctx, names: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified image builders, if the image builder names are provided. Otherwise, all image builders in the account are described.

    Args:
        names(List, optional): The names of the image builders to describe. Defaults to None.
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_image_builders",
        op_kwargs={"Names": names, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, name: str, appstream_agent_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts the specified image builder.

    Args:
        name(str): The name of the image builder.
        appstream_agent_version(str, optional): The version of the AppStream 2.0 agent to use for this image builder. To use the latest version of the AppStream 2.0 agent, specify [LATEST]. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.init.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.init.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="start_image_builder",
        op_kwargs={"Name": name, "AppstreamAgentVersion": appstream_agent_version},
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the specified image builder.

    Args:
        name(str): The name of the image builder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.init.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.init.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="stop_image_builder",
        op_kwargs={"Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def reset(hub, ctx, organization_id: str, user_id: str, password: str) -> Dict:
    r"""
    **Autogenerated function**

    Allows the administrator to reset the password for a user.

    Args:
        organization_id(str): The identifier of the organization that contains the user for which the password is reset.
        user_id(str): The identifier of the user for whom the password is reset.
        password(str): The new password for the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.password.reset(
                ctx, organization_id=value, user_id=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.password.reset organization_id=value, user_id=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="reset_password",
        op_kwargs={
            "OrganizationId": organization_id,
            "UserId": user_id,
            "Password": password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    bucket: str,
    key: str,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns torrent files from a bucket. BitTorrent can save you bandwidth when you're distributing large files. For more information about BitTorrent, see Using BitTorrent with Amazon S3.  You can get torrent only for objects that are less than 5 GB in size, and that are not encrypted using server-side encryption with a customer-provided encryption key.  To use GET, you must have READ access to the object. This action is not supported by Amazon S3 on Outposts. The following action is related to GetObjectTorrent:    GetObject

    Args:
        bucket(str): The name of the bucket containing the object for which to get the torrent files.
        key(str): The object key for which to get the information.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.torrent.get(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.torrent.get bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_object_torrent",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, skill_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Makes a private skill unavailable for enrolled users and prevents them from enabling it on their devices.

    Args:
        skill_id(str):  The private skill ID you want to make unavailable for enrolled users.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.from_.user.disassociate(
                ctx, skill_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.from_.user.disassociate skill_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="disassociate_skill_from_users",
        op_kwargs={"SkillId": skill_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, user_stack_associations: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified users from the specified stacks.

    Args:
        user_stack_associations(List): The list of UserStackAssociation objects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.disassociate_user_stack.batch(
                ctx, user_stack_associations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.disassociate_user_stack.batch user_stack_associations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="batch_disassociate_user_stack",
        op_kwargs={"UserStackAssociations": user_stack_associations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str,
    description: str,
    stop_conditions: List,
    actions: Dict,
    role_arn: str,
    targets: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an experiment template.  To create a template, specify the following information:     Targets: A target can be a specific resource in your AWS environment, or one or more resources that match criteria that you specify, for example, resources that have specific tags.    Actions: The actions to carry out on the target. You can specify multiple actions, the duration of each action, and when to start each action during an experiment.    Stop conditions: If a stop condition is triggered while an experiment is running, the experiment is automatically stopped. You can define a stop condition as a CloudWatch alarm.   For more information, see the AWS Fault Injection Simulator User Guide.

    Args:
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        description(str): A description for the experiment template. Can contain up to 64 letters (A-Z and a-z).
        stop_conditions(List): The stop conditions.
        targets(Dict, optional): The targets for the experiment. Defaults to None.
        actions(Dict): The actions for the experiment.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that grants the AWS FIS service permission to perform service actions on your behalf.
        tags(Dict, optional): The tags to apply to the experiment template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.experiment.template.create(
                ctx,
                client_token=value,
                description=value,
                stop_conditions=value,
                actions=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.experiment.template.create client_token=value, description=value, stop_conditions=value, actions=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="create_experiment_template",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "stopConditions": stop_conditions,
            "targets": targets,
            "actions": actions,
            "roleArn": role_arn,
            "tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified experiment template.

    Args:
        id_(str): The ID of the experiment template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.experiment.template.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.experiment.template.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="delete_experiment_template",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified experiment template.

    Args:
        id_(str): The ID of the experiment template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.experiment.template.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.experiment.template.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="get_experiment_template",
        op_kwargs={"id": id_},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists your experiment templates.

    Args:
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.experiment.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.experiment.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="list_experiment_templates",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    id_: str,
    description: str = None,
    stop_conditions: List = None,
    targets: Dict = None,
    actions: Dict = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified experiment template.

    Args:
        id_(str): The ID of the experiment template.
        description(str, optional): A description for the template. Defaults to None.
        stop_conditions(List, optional): The stop conditions for the experiment. Defaults to None.
        targets(Dict, optional): The targets for the experiment. Defaults to None.
        actions(Dict, optional): The actions for the experiment. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of an IAM role that grants the AWS FIS service permission to perform service actions on your behalf. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.experiment.template.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.experiment.template.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="update_experiment_template",
        op_kwargs={
            "id": id_,
            "description": description,
            "stopConditions": stop_conditions,
            "targets": targets,
            "actions": actions,
            "roleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the Snow Family service limit for your account, and also the number of Snow devices your account has in use. The default service limit for the number of Snow devices that you can have at one time is 1. If you want to increase your service limit, contact AWS Support.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.snowball_usage.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.snowball_usage.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="snowball", operation="get_snowball_usage", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, domain: str, domain_owner: str = None, policy_revision: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Deletes the resource policy set on a domain.

    Args:
        domain(str):  The name of the domain associated with the resource policy to be deleted. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        policy_revision(str, optional):  The current revision of the resource policy to be deleted. This revision is used for optimistic locking, which prevents others from overwriting your changes to the domain's resource policy. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.permission_policy.delete(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.permission_policy.delete domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="delete_domain_permissions_policy",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "policyRevision": policy_revision,
        },
    )


async def get(hub, ctx, domain: str, domain_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns the resource policy attached to the specified domain.    The policy is a resource-based policy, not an identity-based policy. For more information, see Identity-based policies and resource-based policies  in the AWS Identity and Access Management User Guide.

    Args:
        domain(str):  The name of the domain to which the resource policy is attached. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.permission_policy.get(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.permission_policy.get domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="get_domain_permissions_policy",
        op_kwargs={"domain": domain, "domainOwner": domain_owner},
    )


async def put(
    hub,
    ctx,
    domain: str,
    policy_document: str,
    domain_owner: str = None,
    policy_revision: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Sets a resource policy on a domain that specifies permissions to access it.   When you call PutDomainPermissionsPolicy, the resource policy on the domain is ignored when evaluting permissions. This ensures that the owner of a domain cannot lock themselves out of the domain, which would prevent them from being able to update the resource policy.

    Args:
        domain(str):  The name of the domain on which to set the resource policy. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        policy_revision(str, optional):  The current revision of the resource policy to be set. This revision is used for optimistic locking, which prevents others from overwriting your changes to the domain's resource policy. . Defaults to None.
        policy_document(str):  A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided domain. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.permission_policy.put(
                ctx, domain=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.permission_policy.put domain=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="put_domain_permissions_policy",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "policyRevision": policy_revision,
            "policyDocument": policy_document,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    image_name: str,
    role_arn: str,
    description: str = None,
    display_name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom SageMaker image. A SageMaker image is a set of image versions. Each image version represents a container image stored in Amazon Container Registry (ECR). For more information, see Bring your own SageMaker image.

    Args:
        description(str, optional): The description of the image. Defaults to None.
        display_name(str, optional): The display name of the image. If not provided, ImageName is displayed. Defaults to None.
        image_name(str): The name of the image. Must be unique to your account.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.
        tags(List, optional): A list of tags to apply to the image. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.init.create(
                ctx, image_name=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.init.create image_name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_image",
        op_kwargs={
            "Description": description,
            "DisplayName": display_name,
            "ImageName": image_name,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, image_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a SageMaker image and all versions of the image. The container images aren't deleted.

    Args:
        image_name(str): The name of the image to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.init.delete(ctx, image_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.init.delete image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_image",
        op_kwargs={"ImageName": image_name},
    )


async def describe(hub, ctx, image_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a SageMaker image.

    Args:
        image_name(str): The name of the image to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.init.describe(ctx, image_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.init.describe image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_image",
        op_kwargs={"ImageName": image_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the images in your account and their properties. The list can be filtered by creation time or modified time, and whether the image name contains a specified string.

    Args:
        creation_time_after(str, optional): A filter that returns only images created on or after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only images created on or before the specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only images modified on or after the specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only images modified on or before the specified time. Defaults to None.
        max_results(int, optional): The maximum number of images to return in the response. The default value is 10. . Defaults to None.
        name_contains(str, optional): A filter that returns only images whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the previous call to ListImages didn't return the full set of images, the call returns a token for getting the next set of images. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CREATION_TIME. Defaults to None.
        sort_order(str, optional): The sort order. The default value is DESCENDING. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_images",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def update(
    hub,
    ctx,
    image_name: str,
    delete_properties: List = None,
    description: str = None,
    display_name: str = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the properties of a SageMaker image. To change the image's tags, use the AddTags and DeleteTags APIs.

    Args:
        delete_properties(List, optional): A list of properties to delete. Only the Description and DisplayName properties can be deleted. Defaults to None.
        description(str, optional): The new description for the image. Defaults to None.
        display_name(str, optional): The new display name for the image. Defaults to None.
        image_name(str): The name of the image to update.
        role_arn(str, optional): The new Amazon Resource Name (ARN) for the IAM role that enables Amazon SageMaker to perform tasks on your behalf. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.init.update(ctx, image_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.init.update image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_image",
        op_kwargs={
            "DeleteProperties": delete_properties,
            "Description": description,
            "DisplayName": display_name,
            "ImageName": image_name,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, transform_id: str, task_run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels (stops) a task run. Machine learning task runs are asynchronous tasks that Glue runs on your behalf as part of various machine learning workflows. You can cancel a machine learning task run at any time by calling CancelMLTaskRun with a task run's parent transform's TransformID and the task run's TaskRunId.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.
        task_run_id(str): A unique identifier for the task run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.task_run.cancel(
                ctx, transform_id=value, task_run_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.task_run.cancel transform_id=value, task_run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="cancel_ml_task_run",
        op_kwargs={"TransformId": transform_id, "TaskRunId": task_run_id},
    )


async def get(hub, ctx, transform_id: str, task_run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details for a specific task run on a machine learning transform. Machine learning task runs are asynchronous tasks that Glue runs on your behalf as part of various machine learning workflows. You can check the stats of any task run by calling GetMLTaskRun with the TaskRunID and its parent transform's TransformID.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.
        task_run_id(str): The unique identifier of the task run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.task_run.get(ctx, transform_id=value, task_run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.task_run.get transform_id=value, task_run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_ml_task_run",
        op_kwargs={"TransformId": transform_id, "TaskRunId": task_run_id},
    )


async def get_all(
    hub,
    ctx,
    transform_id: str,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
    sort: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of runs for a machine learning transform. Machine learning task runs are asynchronous tasks that Glue runs on your behalf as part of various machine learning workflows. You can get a sortable, filterable list of machine learning task runs by calling GetMLTaskRuns with their parent transform's TransformID and other optional parameters as documented in this section. This operation returns a list of historic runs and must be paginated.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.
        next_token(str, optional): A token for pagination of the results. The default is empty. Defaults to None.
        max_results(int, optional): The maximum number of results to return. . Defaults to None.
        filter_(Dict, optional): The filter criteria, in the TaskRunFilterCriteria structure, for the task run. Defaults to None.
        sort(Dict, optional): The sorting criteria, in the TaskRunSortCriteria structure, for the task run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.task_run.get_all(ctx, transform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.task_run.get_all transform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_ml_task_runs",
        op_kwargs={
            "TransformId": transform_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filter": filter_,
            "Sort": sort,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, pipeline_name: str, pipeline_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.

    Args:
        pipeline_name(str): The name of the pipeline about which you want to get execution details.
        pipeline_execution_id(str): The ID of the pipeline execution about which you want to get execution details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.execution.get(
                ctx, pipeline_name=value, pipeline_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.execution.get pipeline_name=value, pipeline_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_pipeline_execution",
        op_kwargs={
            "pipelineName": pipeline_name,
            "pipelineExecutionId": pipeline_execution_id,
        },
    )


async def list_all(
    hub, ctx, pipeline_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a summary of the most recent executions for a pipeline.

    Args:
        pipeline_name(str): The name of the pipeline for which you want to get execution summary information.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value. Pipeline history is limited to the most recent 12 months, based on pipeline execution start times. Default value is 100. Defaults to None.
        next_token(str, optional): The token that was returned from the previous ListPipelineExecutions call, which can be used to return the next set of pipeline executions in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.execution.list_all(
                ctx, pipeline_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.execution.list_all pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="list_pipeline_executions",
        op_kwargs={
            "pipelineName": pipeline_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(hub, ctx, name: str, client_request_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts the specified pipeline. Specifically, it begins processing the latest commit to the source location specified as part of the pipeline.

    Args:
        name(str): The name of the pipeline to start.
        client_request_token(str, optional): The system-generated unique ID used to identify a unique execution request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.execution.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.execution.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="start_pipeline_execution",
        op_kwargs={"name": name, "clientRequestToken": client_request_token},
    )


async def stop(
    hub,
    ctx,
    pipeline_name: str,
    pipeline_execution_id: str,
    abandon: bool = None,
    reason: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stops the specified pipeline execution. You choose to either stop the pipeline execution by completing in-progress actions without starting subsequent actions, or by abandoning in-progress actions. While completing or abandoning in-progress actions, the pipeline execution is in a Stopping state. After all in-progress actions are completed or abandoned, the pipeline execution is in a Stopped state.

    Args:
        pipeline_name(str): The name of the pipeline to stop.
        pipeline_execution_id(str): The ID of the pipeline execution to be stopped in the current stage. Use the GetPipelineState action to retrieve the current pipelineExecutionId.
        abandon(bool, optional): Use this option to stop the pipeline execution by abandoning, rather than finishing, in-progress actions.  This option can lead to failed or out-of-sequence tasks. . Defaults to None.
        reason(str, optional): Use this option to enter comments, such as the reason the pipeline was stopped. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.execution.stop(
                ctx, pipeline_name=value, pipeline_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.execution.stop pipeline_name=value, pipeline_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="stop_pipeline_execution",
        op_kwargs={
            "pipelineName": pipeline_name,
            "pipelineExecutionId": pipeline_execution_id,
            "abandon": abandon,
            "reason": reason,
        },
    )
